.. _api-index:

##############
The Siphon API
##############

.. toctree::
   :maxdepth: 2

   catalog
   metadata
   ncssdataset
   http_util
   ncss
   radarserver

* :ref:`genindex`
* :ref:`modindex`
